==> haskell-equivalence-0.4.1.1-47.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 equivalence
version:              0.4.1.1
visibility:           public
id:                   equivalence-0.4.1.1-5Jhm452h9UL8ys4jUY2uPu
key:                  equivalence-0.4.1.1-5Jhm452h9UL8ys4jUY2uPu
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Patrick Bahr
stability:            provisional
homepage:             https://github.com/pa-ba/equivalence
synopsis:
    Maintaining an equivalence relation implemented as union-find using STT.

description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).

category:             Algorithms, Data
abi:                  1e30eb73cf62a5f374ccfbbcc534ed07
exposed:              True
exposed-modules:      Data.Equivalence.Monad Data.Equivalence.STT
import-dirs:          /usr/lib/ghc-9.6.6/site-local/equivalence-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/equivalence-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/equivalence-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-equivalence
hs-libraries:         HSequivalence-0.4.1.1-5Jhm452h9UL8ys4jUY2uPu
depends:
    STMonadTrans-0.4.8.1-FWRorMxbkTH44hCyMeaQb3 base-4.18.2.1
    containers-0.6.7 mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html:         /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.4.1.1-48-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 equivalence
version:              0.4.1.1
visibility:           public
id:                   equivalence-0.4.1.1-FAS8CBbtN4hINIAfROWUf8
key:                  equivalence-0.4.1.1-FAS8CBbtN4hINIAfROWUf8
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Patrick Bahr
stability:            provisional
homepage:             https://github.com/pa-ba/equivalence
synopsis:
    Maintaining an equivalence relation implemented as union-find using STT.

description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).

category:             Algorithms, Data
abi:                  380e71e101b1cc003fbfdfcfe83679f6
exposed:              True
exposed-modules:      Data.Equivalence.Monad Data.Equivalence.STT
import-dirs:          /usr/lib/ghc-9.6.6/site-local/equivalence-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/equivalence-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/equivalence-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-equivalence
hs-libraries:         HSequivalence-0.4.1.1-FAS8CBbtN4hINIAfROWUf8
depends:
    STMonadTrans-0.4.8.1-4gC6jCTwh4OLa1rk9sAdBj base-4.18.2.1
    containers-0.6.7 mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html:         /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
